Option Explicit

Dim gstrSourcePath, gstrDestinationPath
Dim objArgs
Set objArgs = WScript.Arguments
If objArgs.Count = 2 Then 
	gstrSourcePath = objArgs(0)
	gstrDestinationPath = objArgs(1)
Else
	gstrSourcePath = "C:\documents\projects\devimport\sample.doc"
	gstrDestinationPath = "C:\documents\projects\devimport\sampleOut.xml"
End If

ParseDoc gstrSourcePath
SaveXml gstrDestinationPath

Sub ParseDoc(strFilePath)
	Dim oApp, oDocument, oParagraphs, oStyleRange, oDescrRange
	Dim strName, strStyle, strDescription
	Set oApp = CreateObject("Word.Application")
	Set oDocument = oApp.Documents.Open(strFilePath, False, True)
	Set oParagraphs = oDocument.Paragraphs
	Dim i
	For i = 1 to oParagraphs.Count - 3
		strName = RemoveCR(oParagraphs.Item(i).Range.Text)
		If Len(strName) > 0 Then
			Set oStyleRange = oParagraphs.Item(i + 1).Range
			strStyle = RemoveCR(oStyleRange.Text)
			Set oDescrRange = oParagraphs.Item(i + 2).Range
			If oStyleRange.Bold And Not oDescrRange.Bold Then
				strDescription = RemoveCR(oDescrRange.Text)
				If Len(strStyle) > 0 _
					And Len(strDescription) > 0 Then
					InsertRequirement strName, strStyle, strDescription
				End If
			End If

			i = i + 3
		End If
	Next
	oDocument.Close()
	oApp.Quit()
End Sub

Function RemoveCR(strSource)
	Dim strDestination
	strDestination = strSource
	If Len(strSource) > 0 Then
		If Right(strSource, 1) = vbCR Then
			strDestination = Left(strSource, Len(strSource) - 1)
		End If
	End If
	RemoveCR = strDestination
End Function

Sub InsertRequirement(strName, strStyle, strDescription)
	Dim strPmId, strRequirementId
	strPmId = GetPmId(strStyle)
	strRequirementId = GetRequirementId(strStyle)
	InsertTaskTo strPmId, strRequirementId, strName, strDescription
End Sub

Sub InsertTaskTo(strPmId, strRequirementId, strName, strDescription)
	Dim oPmNode
	Set oPmNode = GetCategoryNode(strPmId, Nothing)
	Dim oRequirementNode
	Set oRequirementNode = GetCategoryNode(strRequirementId, oPmNode)
	InsertTask oRequirementNode, strName, strDescription
End Sub

'R5c-G1
Function GetPmId(strStyle)
	GetPmId = FindToken(strStyle, "G")
End Function

Function GetRequirementId(strStyle)
	Dim strFullId
	strFullId = FindToken(strStyle, "R")
	GetRequirementId = strFullId
	If Len(strFullId) > 0 Then
		If Not IsNumeric(Right(strFullId, 1)) Then
			GetRequirementId = Left(strFullId, Len(strFullId) - 1)
		End If
	End If
End Function

Function FindToken(strStyle, strTokenName)
	Dim arrTokens, strToken, i
	arrTokens = Split(strStyle, "-")
	For i = LBound(arrTokens) To UBound(arrTokens)
		strToken = arrTokens(i)
		If Left(strToken, Len(strTokenName)) = strTokenName Then
			FindToken = strToken
		End If
	Next
End Function

' XML
Function GetCategoryNode(strName, oParentNode)
	If oParentNode Is Nothing Then
		Set oParentNode = GetRootNode()
	End If
	Dim oNode, strQuery
	strQuery = "CATEGORY[@NAME=""" & strName & """]"
	Set oNode = oParentNode.selectSingleNode(strQuery)
	If oNode Is Nothing Then
		Set oNode = CreateCategoryNode(oParentNode, strName)
	End If
	Set GetCategoryNode = oNode
End Function

Sub InsertTask(oParentNode, strName, strDescription)
	If Not (oParentNode Is Nothing) Then
		Dim xmlDoc, oNewNode
		Set xmlDoc = oParentNode.ownerDocument
		Set oNewNode = xmlDoc.createElement("TASK")
		SetAttribute oNewNode, "NAME", strName
		SetTextNode oNewNode, "DESCRIPTION", strDescription
		oParentNode.appendChild(oNewNode)
	End If
End Sub

Function CreateCategoryNode(oParentNode, strName)
	If Not (oParentNode Is Nothing) Then
		Dim xmlDoc, oNewNode
		Set xmlDoc = oParentNode.ownerDocument
		Set oNewNode = xmlDoc.createElement("CATEGORY")
		SetAttribute oNewNode, "NAME", strName
		Set CreateCategoryNode = oParentNode.appendChild(oNewNode)
	End If
End Function

Sub SetAttribute(oNode, strName, value)
	If Not (oNode Is Nothing) Then
		Dim xmlDoc, oNameAttr
		Set xmlDoc = oNode.ownerDocument
		Set oNameAttr = xmlDoc.createAttribute(strName)
		oNameAttr.nodeValue = value
		oNode.attributes.setNamedItem oNameAttr
	End If
End Sub

Sub SetTextNode(oNode, strName, text)
	If Not (oNode Is Nothing) Then
		Dim xmlDoc, oDescrNode
		Set xmlDoc = oNode.ownerDocument
		Set oDescrNode = xmlDoc.createElement("DESCRIPTION")
		oDescrNode.text = text
		oNode.appendChild oDescrNode
	End If
End Sub

Dim gXmlDoc
Function GetRootNode()
	If IsEmpty(gXmlDoc) Then
		Dim ptrRoot
		Set gXmlDoc = CreateObject("Msxml2.DOMDocument.4.0")
		gXmlDoc.setProperty "SelectionLanguage", "XPath"
		Set ptrRoot = gXmlDoc.createElement("ROOT")
		gXmlDoc.appendChild(ptrRoot)
	End If
	Set GetRootNode = gXmlDoc.documentElement
End Function

Sub SaveXml(strFilePath)
	If Not IsEmpty(gXmlDoc) Then
		gXmlDoc.save strFilePath
	End If
End Sub
