<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt" xmlns:vb="urn:the-xml-files:xslt-vb" xmlns:js="urn:the-xml-files:xslt-js" version="1.0">
	<xsl:output method="html"/>
	<xsl:param name="ReportingPeriodStart"/>
	<xsl:param name="ReportingPeriodEnd"/>
	<xsl:param name="Is24HoursFormat"/>
	<xsl:include href="WeekProcessing.inc"/>
	<xsl:include href="HolidaysProcessing.inc"/>
	<xsl:include href="TimeSheetProcessing.inc"/>
	<xsl:include href="DayTimeProcessing.inc"/>
	<xsl:include href="Common.inc"/>
	<xsl:include href="ReportCSS.inc"/>
	<xsl:key name="task_key" match="//DAY[vb:IsDateOfPeriod(string(@DATE))]/PLANENTRY" use="@TASKID"/>
	<xsl:template match="/">
		<xsl:value-of select="vb:PushHolidays(//HOLIDAYS/HOLIDAY/@DATE)"/>
		<xsl:value-of select="vb:SetReportingPeriod($ReportingPeriodStart, $ReportingPeriodEnd)"/>
		<xsl:value-of select="vb:SetTimeFormat($Is24HoursFormat)"/>
		<HTML>
			<HEAD>
				<TITLE>{Report}: {DailyTimePlan} (<xsl:value-of select="vb:FormatThisPeriod()"/>)</TITLE>
				<META NAME="Report" CONTENT="Daily Time Plan"/>
				<STYLE ID="ReportStyle">
					<xsl:value-of select="$css"/>
				</STYLE>
			</HEAD>
			<BODY>
				<xsl:for-each select="//PROPERTIES">
					<table border="0" cellpadding="2" cellspacing="2">
						<tr>
							<td valign="top">
								<table width="100%" border="0" class="headingtable">
									<tr>
										<td class="righttitle">{Name}: </td>
										<td class="employee"><xsl:value-of select="@AUTHOR"/></td>
									</tr>
									<tr>
										<td class="righttitle">{ReportingPeriod}: </td>
										<td class="underlined"><xsl:value-of select="vb:FormatThisPeriod()"/></td>
									</tr>
									<tr>
										<td colspan="2" class="emptyrow"></td>
									</tr>
								</table>
							</td>
						</tr>
						<tr><td colspan="2" class="doctitle">{DailyTimePlan}</td></tr>
					</table>
				</xsl:for-each>
				<xsl:call-template name="AllDays">
					<xsl:with-param name="currentContext" select="/"/>
				</xsl:call-template>
			</BODY>
		</HTML>
	</xsl:template>
	<xsl:template name="AllDays">
		<xsl:param name="currentContext"/>
		<xsl:value-of select="vb:ResetStart()"/>
		<xsl:for-each select="ms:node-set($weekDaysList)/IT">
			<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
				<xsl:call-template name="DayTasks">
					<xsl:with-param name="dayIterator"><xsl:value-of select="vb:GetDaysIteratorString()"/></xsl:with-param>
					<xsl:with-param name="currentContext" select="$currentContext"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:value-of select="vb:MoveNextDay()"/>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="DayTasks">
		<xsl:param name="dayIterator"/>
		<xsl:param name="currentContext"/>
		<xsl:variable name="dayPlanEntryCount" select="count(ms:node-set($currentContext)//DAY[vb:IsEqualDate(string(@DATE), string($dayIterator))]/PLANENTRY)"/>
			<xsl:if test="vb:IsDateHasTasks($dayPlanEntryCount)">

		<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0">
			<THEAD style="display: table-header-group">
				<TR>
					<TD class="dayHead" colspan="6">
						<xsl:call-template name="HolidayColoring">
							<xsl:with-param name="defaultColor">#FFFFFF</xsl:with-param>
							<xsl:with-param name="holidayColor">#EEEEEE</xsl:with-param>
						</xsl:call-template>
						<xsl:value-of select="vb:ToWeekDayNameLong(string($dayIterator))"/></TD></TR>
				<TR>
					<TD class="leftHeadCell" width="15"> </TD>
					<TD class="headCell" width="250">{Task} {name}</TD>
					<TD class="headCell" width="60">{Start}</TD>
					<TD class="headCell" width="60">{Finish}</TD>
					<TD class="headCell" width="60">{Duration}</TD>
					<TD class="headCell" width="250">{Comments}</TD>
				</TR>
			</THEAD>
			<TBODY>
				<xsl:for-each select="ms:node-set($currentContext)//DAY[vb:IsEqualDate(string(@DATE), string($dayIterator))]/PLANENTRY">
					<TR>
						<xsl:variable name="taskId" select="@TASKID"/>
						<TD class="taskCell" width="15"> <xsl:if test="ms:node-set($currentContext)//TASK[@ID=$taskId]/@STATUS=2">x</xsl:if></TD>
						<TD class="taskDescription" width="250"><xsl:value-of select="ms:node-set($currentContext)//TASK[@ID=$taskId]/@NAME"/></TD>
						<TD class="tableCell" width="60"><xsl:value-of select="vb:FormatTime(string(@STARTTIME))"/></TD>
						<TD class="tableCell" width="60"><xsl:value-of select="vb:FormatTime(string(@ENDTIME))"/></TD>
						<TD class="tableCell" width="60"><xsl:value-of select="vb:HoursDiff(string(@STARTTIME), string(@ENDTIME))"/></TD>
						<TD class="taskDescription" width="250"><xsl:value-of select="DESCRIPTION"/> </TD>
					</TR>
				</xsl:for-each>
				<xsl:call-template name="EmptyRow"/>
				<xsl:call-template name="EmptyRow"/>
				<xsl:call-template name="EmptyRow"/>
				<xsl:call-template name="EmptyRow"/>
				<xsl:call-template name="EmptyRow"/>
				<xsl:call-template name="EmptyRow"/>
				<xsl:call-template name="EmptyRow"/>
			</TBODY>
		</TABLE>
				<BR/>
		</xsl:if>
	</xsl:template>
	<xsl:template name="EmptyRow">
		<TR>
			<TD class="taskCell" width="15"> </TD>
			<TD class="taskDescription" width="250"> </TD>
			<TD class="tableCell" width="60"> </TD>
			<TD class="tableCell" width="60"> </TD>
			<TD class="tableCell" width="60"> </TD>
			<TD class="taskDescription" width="250"> </TD>
		</TR>
	</xsl:template>
	<xsl:template name="HolidayColoring">
		<xsl:param name="defaultColor"/>
		<xsl:param name="holidayColor"/>
		<xsl:attribute name="BGCOLOR">
			<xsl:choose>
				<xsl:when test="vb:IsHoliday(vb:GetDaysIteratorString())"><xsl:value-of select="$holidayColor"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$defaultColor"/></xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
	</xsl:template>
</xsl:stylesheet>
