<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt" xmlns:vb="urn:the-xml-files:xslt-vb" xmlns:js="urn:the-xml-files:xslt-js" version="1.0">
	<xsl:output method="html"/>
	<xsl:param name="AffectedCategory"/>
	<xsl:include href="Common.inc"/>
	<xsl:include href="LocaleIndependent.inc"/>
	<xsl:include href="PlanEntryProcessing.inc"/>
	<xsl:include href="Intending.inc"/>
	<xsl:include href="Subprojects.inc"/>
	<xsl:include href="ReportCSS.inc"/>
	<xsl:key name="task_key" match="//DAY/PLANENTRY" use="@TASKID"/>
	<xsl:template match="/">
		<xsl:variable name="projectTitle">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="@NAME"/>
			</xsl:for-each>
			<xsl:if test="$AffectedCategory = 0">
			All tasks
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="parentProjectTitle"> 
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]"> 
			<xsl:value-of select="vb:GetParentNames(.)"/>
			<xsl:value-of select="@NAME"/>
			</xsl:for-each> 
			<xsl:if test="$AffectedCategory = 0">
			All tasks
			</xsl:if>
		</xsl:variable>
		<HTML>
			<HEAD>
				<META NAME="Report" CONTENT="{StageEstimation}"/>
				<TITLE>{Report}: {StageEstimation} {of} <xsl:value-of select="$projectTitle"/>.</TITLE>
				<STYLE ID="ReportStyle">
				<xsl:value-of select="$css"/>
				</STYLE>
			</HEAD>
			<BODY>
				<H2>{StageEstimation}</H2>
				<xsl:for-each select="//PROPERTIES">
					<table border="0" cellpadding="2" cellspacing="0">
						<tr>
						<td class="righttitle">{Employee}: </td>
						<td class="underlined"><xsl:value-of select="@AUTHOR"/></td>
						</tr>
						<tr>
						<td class="righttitle">{Category}: </td>
						<td class="underlined"><xsl:value-of select="$parentProjectTitle"/></td>
						</tr>
						<tr>
						<td class="righttitle">{Date}: </td>
						<td class="underlined"><xsl:value-of select="vb:GetCurrentDate()"/></td>
						</tr>
					</table>
				</xsl:for-each>
				
				<br/>
				<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0" WIDTH="100%">
					<THEAD style="display: table-header-group">
					<TR>
						<TH class="leftHeadCell">{Name}</TH>
						<TH class="headCell">{Priority}</TH>
						<TH class="headCell">{Status}</TH>
						<TH class="headCell">{Estimation} ({hours})</TH>
						<TH class="headCell">{Deadline}</TH>
					</TR>
					</THEAD>
					<TBODY>
					<xsl:choose>
					<xsl:when test="$AffectedCategory != 0">
					<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
						<xsl:value-of select="vb:SetBaseIntend(vb:GetIntend(.))"/>
						<xsl:apply-templates select="."/>
					</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
					<xsl:for-each select="ROOT/CATEGORY">
						<xsl:value-of select="vb:SetBaseIntend('')"/>
						<xsl:apply-templates select="."/>
					</xsl:for-each>
					</xsl:otherwise>
					</xsl:choose>
					</TBODY>
				</TABLE>
				
				<BR/>
				<table border="0" cellpadding="2" cellspacing="0">
				<tr><td colspan="2">&#160; </td></tr>
				<tr><td colspan="2">&#160; </td></tr>
				<tr>
				<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
				<td class="signetureCell">{Date}</td>
				</tr>
				<tr><td colspan="2">&#160; </td></tr>
				<tr>
				<td class="signetureCell">{ManagerSignature}</td>
				<td class="signetureCell">{Date}</td>
				</tr>
				</table>
			</BODY>
		</HTML>
	</xsl:template>

	<xsl:template match="CATEGORY">
	<xsl:if test=".//TASK[@STATUS != 2]">
		<xsl:variable name="estimatesCat" select="sum(.//TASK[@STATUS != 2]/@ESTIMATION)"/>
		<xsl:variable name="catDeadline" select="vb:GetMaxDate(.//TASK[@STATUS != 2]/@DEADLINE)"/>
		<TR>
			<TD class="categoryCell" colspan="3">
				<xsl:value-of select="vb:GetIntend(.)"/><xsl:value-of select="@NAME"/></TD>
			<TD class="categoryTotal"><xsl:value-of select="vb:FormatNumberEx(js:ToDbl($estimatesCat))"/></TD>
			<TD class="categoryTotal"><xsl:value-of select="$catDeadline"/></TD>
		</TR>

		<xsl:if test="./TASK">
			<xsl:for-each select="./TASK">
				<xsl:sort select="@STATUS" order="descending"/>
				<xsl:sort select="@IMPORTANCE"/>
				<xsl:sort select="@DEADLINE"/>
				<xsl:sort select="@NAME"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="./CATEGORY">
		<xsl:if test=".//TASK">
			<xsl:for-each select="./CATEGORY">
				<xsl:sort select="@NAME"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</xsl:if>
		</xsl:if>
	</xsl:if>
	</xsl:template>

	<xsl:template match="TASK">
		<xsl:if test="@STATUS != 2">
			<TR>
			<TD class="taskCell"><xsl:value-of select="vb:GetRecentIntend()"/><xsl:value-of select="@NAME"/></TD>
			<TD class="freeTableCell"><xsl:value-of select="vb:GetImportanceString(@IMPORTANCE)"/></TD>
			<TD class="freeTableCell"><xsl:value-of select="vb:GetStatusString(@STATUS)"/></TD>
			<TD class="freeTableCell"><xsl:value-of select="vb:FormatNumberEx(js:ToDbl(string(@ESTIMATION)))"/></TD>
			<TD class="freeTableCell"><xsl:value-of select="vb:FormatDate(string(@DEADLINE))"/></TD>
			</TR>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
